@@ -41,11 +41,11 @@ pub fn make_has_many(
         let child_builder_ident = format_ident!("{}Builder", &struct_ident.to_string());
         let join = {
             let x = format!(
-                "INNER JOIN {} ON {}.{} = {{}}.id",
+                "{{}} JOIN {} ON {}.{} = {{}}.id",
                 child_table_name, child_table_name_as, has_many.foreign_key,
             );
             let y = format!(
-                "INNER JOIN {} AS {{0}} ON {{0}}.{} = {{1}}.id",
+                "{{0}} JOIN {} AS {{1}} ON {{1}}.{} = {{2}}.id",
                 child_table_name, has_many.foreign_key,
             );
             let parent_table_name = quote! {
@@ -53,8 +53,17 @@ pub fn make_has_many(
             };
             quote! {
                 match &self.#builder_field.as_ref().map(|x| x.table_name_as.as_ref()).flatten() {
-                    Some(table_name_as) => format!(#y, table_name_as, #parent_table_name),
-                    None => format!(#x, #parent_table_name)
+                    Some(table_name_as) => format!(
+                        #y,
+                        if builder.outer_join { "LEFT OUTER" } else { "INNER" },
+                        table_name_as,
+                        #parent_table_name
+                    ),
+                    None => format!(
+                        #x,
+                        if builder.outer_join { "LEFT OUTER" } else { "INNER" },
+                        #parent_table_name
+                    )
                 }
             }
         };
